BaseDecoder class

Base class for all decoder configurations.

Every decoder extends this and adds its own parameters.

See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/barcode/ScannerConfig/

Implementers

Constructors

BaseDecoder({bool? enabled})
const

Properties

enabled bool?
Whether this symbology decoder is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited