Code11Decoder class

Inheritance

Constructors

Code11Decoder({bool? enabled, int? length1, int? length2, bool? redundancy, VerifyCheckDigit? verifyCheckDigit, bool? reportCheckDigit})
const
Code11Decoder.fromMap(Map<String, dynamic> map)
factory

Properties

enabled bool?
Whether this symbology decoder is enabled.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length1 int?
final
length2 int?
final
redundancy bool?
final
reportCheckDigit bool?
Whether to include the check digit in reported data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifyCheckDigit VerifyCheckDigit?
Number of check digits to verify.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited