Code128Decoder class

Inheritance

Constructors

Code128Decoder({bool? enabled, int? length1, int? length2, bool? redundancy, bool? enablePlain, bool? enableEan128, bool? enableIsbt128, Isbt128ContactMode? isbt128ConcatMode, bool? checkIsbtTable, SecurityLevel? securityLevel, bool? reducedQuietZone})
const
Code128Decoder.fromMap(Map<String, dynamic> map)
factory

Properties

checkIsbtTable bool?
Whether to check the ISBT table for valid sequences.
final
enabled bool?
Whether this symbology decoder is enabled.
finalinherited
enableEan128 bool?
Whether to enable EAN 128 (GS1-128) decoding.
final
enableIsbt128 bool?
Whether to enable ISBT 128 decoding.
final
enablePlain bool?
Whether to enable plain Code 128 decoding.
final
hashCode int
The hash code for this object.
no setterinherited
isbt128ConcatMode Isbt128ContactMode?
ISBT 128 concatenation mode.
final
length1 int?
final
length2 int?
final
reducedQuietZone bool?
Whether to allow decoding with reduced quiet zone.
final
redundancy bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityLevel SecurityLevel?
Security level for decoding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited