Code39Decoder class

Inheritance

Constructors

Code39Decoder({bool? enabled, int? length1, int? length2, bool? verifyCheckDigit, bool? reportCheckDigit, bool? fullAscii, bool? redundancy, bool? convertToCode32, bool? reportCode32Prefix, SecurityLevel? securityLevel, bool? reducedQuietZone})
const
Code39Decoder.fromMap(Map<String, dynamic> map)
factory

Properties

convertToCode32 bool?
Whether to convert Code 39 to Code 32.
final
enabled bool?
Whether this symbology decoder is enabled.
finalinherited
fullAscii bool?
Whether to enable full ASCII mode.
final
hashCode int
The hash code for this object.
no setterinherited
length1 int?
final
length2 int?
final
reducedQuietZone bool?
final
redundancy bool?
final
reportCheckDigit bool?
final
reportCode32Prefix bool?
Whether to include the Code 32 prefix in the output.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityLevel SecurityLevel?
final
verifyCheckDigit bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited