CompositeABDecoder class
Composite AB decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- CompositeABDecoder
Constructors
- CompositeABDecoder({bool? enabled, UccLinkMode? uccLinkMode})
-
const
-
CompositeABDecoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uccLinkMode → UccLinkMode?
-
UCC/EAN link mode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited