DotCodeDecoder class

Inheritance

Constructors

DotCodeDecoder({bool? enabled, DotCodeInverse? inverse, DotCodeMirror? mirror})
const
DotCodeDecoder.fromMap(Map<String, dynamic> map)
factory

Properties

enabled bool?
Whether this symbology decoder is enabled.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inverse DotCodeInverse?
Inverse DotCode mode.
final
mirror DotCodeMirror?
Mirror DotCode mode.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited