Ean8Decoder class

Inheritance

Constructors

Ean8Decoder({bool? enabled, bool? convertToEan13})
const
Ean8Decoder.fromMap(Map<String, dynamic> map)
factory

Properties

convertToEan13 bool?
Whether to convert EAN-8 to EAN-13 on output.
final
enabled bool?
Whether this symbology decoder is enabled.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited