I2of5Decoder class

Inheritance

Constructors

I2of5Decoder({bool? enabled, int? length1, int? length2, bool? redundancy, CheckDigitType? verifyCheckDigit, bool? reportCheckDigit, bool? convertToEan13, SecurityLevel? securityLevel, bool? reducedQuietZone, bool? febraban})
const
I2of5Decoder.fromMap(Map<String, dynamic> map)
factory

Properties

convertToEan13 bool?
Whether to convert I 2 of 5 to EAN-13.
final
enabled bool?
Whether this symbology decoder is enabled.
finalinherited
febraban bool?
Whether Febraban (Brazilian banking) mode is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
length1 int?
final
length2 int?
final
reducedQuietZone bool?
final
redundancy bool?
final
reportCheckDigit bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityLevel SecurityLevel?
final
verifyCheckDigit CheckDigitType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited