Matrix2of5Decoder class
Matrix 2 of 5 decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- Matrix2of5Decoder
Constructors
- Matrix2of5Decoder({bool? enabled, int? length1, int? length2, bool? redundancy, bool? reportCheckDigit, bool? verifyCheckDigit})
-
const
-
Matrix2of5Decoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length1 → int?
-
final
- length2 → int?
-
final
- redundancy → bool?
-
final
- reportCheckDigit → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyCheckDigit → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited