MsiDecoder class
MSI decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- MsiDecoder
Constructors
- MsiDecoder({bool? enabled, int? length1, int? length2, bool? redundancy, CheckDigit? checkDigits, CheckDigitScheme? checkDigitScheme, bool? reportCheckDigit})
-
const
-
MsiDecoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- checkDigits → CheckDigit?
-
Number of check digits.
final
- checkDigitScheme → CheckDigitScheme?
-
Check digit scheme.
final
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length1 → int?
-
final
- length2 → int?
-
final
- redundancy → bool?
-
final
- reportCheckDigit → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited