Upce0Decoder class
UPC-E0 decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- Upce0Decoder
Constructors
- Upce0Decoder({bool? enabled, bool? reportCheckDigit, Preamble? preamble, bool? convertToUpca})
-
const
-
Upce0Decoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- convertToUpca → bool?
-
final
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- preamble → Preamble?
-
final
- reportCheckDigit → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited