data/emdk_manager
library
Classes
-
EMDKError
-
Represents an EMDK error with a primary code and optional sub-codes.
-
EMDKResults
-
Result object returned from profile and EMDK operations.
-
EMDKStatusData
-
Status data passed to the EMDKManager StatusListener.
-
ProfileResultData
-
Result data returned from an asynchronous profile processing call.
Exceptions / Errors
-
EMDKException
-
Exception thrown by EMDK core operations (e.g. opening the EMDK manager
or requesting a feature instance) when an error occurs at the SDK level.