result property
The EMDK result describing why the exception was thrown.
May be null when no structured result data is available (e.g. low-level Android exceptions propagated from the native layer).
Implementation
final EMDKResults? result;
The EMDK result describing why the exception was thrown.
May be null when no structured result data is available (e.g. low-level Android exceptions propagated from the native layer).
final EMDKResults? result;