toMap method
Converts this EMDKException to a Map suitable for sending over the platform channel.
Implementation
Map<String, dynamic> toMap() {
return {
'result': result?.toMap(),
'message': message,
};
}
Converts this EMDKException to a Map suitable for sending over the platform channel.
Map<String, dynamic> toMap() {
return {
'result': result?.toMap(),
'message': message,
};
}