EMDKExtendedStatusCode enum
Extended status codes for detailed EMDK result reporting.
See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/EMDKResults/
Values
- none → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('NONE') - profileNotFoundInConfig → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('PROFILE_NOT_FOUND_IN_CONFIG') - featureTypeNotFoundInConfig → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('FEATURE_TYPE_NOT_FOUND_IN_CONFIG') - featureNameNotFoundInConfig → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('FEATURE_NAME_NOT_FOUND_IN_CONFIG') - featureNameNotFoundInExtradata → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('FEATURE_NAME_NOT_FOUND_IN_EXTRADATA') - featureTypeNotFoundInExtradata → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('FEATURE_TYPE_NOT_FOUND_IN_EXTRADATA') - profileNotFoundInExtradata → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('PROFILE_NOT_FOUND_IN_EXTRADATA') - featureNotUniqueInConfig → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('FEATURE_NOT_UNIQUE_IN_CONFIG') - featureNotUniqueInExtradata → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('FEATURE_NOT_UNIQUE_IN_EXTRADATA') - dependencyComponentFailure → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('DEPENDACY_COMPONENT_FAILURE') - generalExceptionOccured → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('GENERAL_EXCEPTION_OCCURED') - namevalueMissmatchInConfig → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('NAMEVALUE_MISSMATCH_IN_CONFIG') - namevalueMismatchInExtradata → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('NAMEVALUE_MISMATCH_IN_EXTRADATA') - invalidProfileConfiguration → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('INVALID_PROFILE_CONFIGURATION') - profileNameFormatError → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('PROFILE_NAME_FORMAT_ERROR') - activitySelectionMergingNotSupported → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('ACTIVITY_SELECTION_MERGING_NOT_SUPPORTED') - invalidValue → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('INVALID_VALUE') - appNotAllowedToSubmitXml → const EMDKExtendedStatusCode
-
const EMDKExtendedStatusCode('APP_NOT_ALLOWED_TO_SUBMIT_XML')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → EMDKExtendedStatusCode
Constants
-
values
→ const List<
EMDKExtendedStatusCode> - A constant List of the values in this enum, in order of their declaration.