EMDKStatusCode enum

Inheritance
Available extensions

Values

success → const EMDKStatusCode
const EMDKStatusCode('SUCCESS')
failure → const EMDKStatusCode
const EMDKStatusCode('FAILURE')
unknown → const EMDKStatusCode
const EMDKStatusCode('UNKNOWN')
nullPointer → const EMDKStatusCode
const EMDKStatusCode('NULL_POINTER')
emptyProfileName → const EMDKStatusCode
const EMDKStatusCode('EMPTY_PROFILENAME')
emdkNotOpened → const EMDKStatusCode
const EMDKStatusCode('EMDK_NOT_OPENED')
checkXml → const EMDKStatusCode
const EMDKStatusCode('CHECK_XML')
previousRequestInProgress → const EMDKStatusCode
const EMDKStatusCode('PREVIOUS_REQUEST_IN_PROGRESS')
processing → const EMDKStatusCode
const EMDKStatusCode('PROCESSING')
noDataListener → const EMDKStatusCode
const EMDKStatusCode('NO_DATA_LISTENER')
featureNotReadyToUse → const EMDKStatusCode
const EMDKStatusCode('FEATURE_NOT_READY_TO_USE')
featureNotSupported → const EMDKStatusCode
const EMDKStatusCode('FEATURE_NOT_SUPPORTED')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) EMDKStatusCode

Constants

values → const List<EMDKStatusCode>
A constant List of the values in this enum, in order of their declaration.