EMDKStatusData class

Status data passed to the EMDKManager StatusListener.

Describes the result of an EMDK open/close operation for a feature.

See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/EMDKManager/

Constructors

EMDKStatusData({EMDKStatusCode? result, EMDKFeatureType? featureType})
const
EMDKStatusData.fromMap(Map<String, dynamic> map)
factory

Properties

featureType EMDKFeatureType?
The feature type this status relates to.
final
hashCode int
The hash code for this object.
no setterinherited
result EMDKStatusCode?
The result of the EMDK status event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited