ProfileResultData class
Result data returned from an asynchronous profile processing call.
See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/ProfileManager/
Constructors
- ProfileResultData({EMDKResults? result, String? profileName, ProfileFlag? profileFlag, String? profileString})
-
const
-
ProfileResultData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- profileFlag → ProfileFlag?
-
The profile flag that was used.
final
- profileName → String?
-
The name of the profile that was processed.
final
- profileString → String?
-
The XML string representation of the profile result.
final
- result → EMDKResults?
-
The result of the profile operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited