NotificationBeep class

Constructors

NotificationBeep({int? time, int? frequency})
const
NotificationBeep.fromMap(Map<String, dynamic> map)
factory

Properties

frequency int?
Frequency of the beep in Hz.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int?
Duration of the beep in milliseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited