NotificationCommand class

Notification command sent to a notification device.

Combines LED, beep, and vibration parameters into one object.

See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/notification/Notification/

Properties

beep NotificationBeepParams?
Beep parameters; null if audio notification is not desired.
final
hashCode int
The hash code for this object.
no setterinherited
led NotificationLEDParams?
LED parameters; null if LED notification is not desired.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vibrate NotificationVibrateParams?
Vibration parameters; null if vibration is not desired.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited