NotificationDeviceIdentifier enum

Inheritance
Available extensions

Values

defaultDevice → const NotificationDeviceIdentifier
const NotificationDeviceIdentifier('DEFAULT')
bluetoothImagerRs6000 → const NotificationDeviceIdentifier
const NotificationDeviceIdentifier('BLUETOOTH_IMAGER_RS6000')
externalVibrator1 → const NotificationDeviceIdentifier
const NotificationDeviceIdentifier('EXTERNAL_VIBRATOR1')
bluetoothImagerRs5100 → const NotificationDeviceIdentifier
const NotificationDeviceIdentifier('BLUETOOTH_IMAGER_RS5100')
bluetoothGeneric → const NotificationDeviceIdentifier
const NotificationDeviceIdentifier('BLUETOOTH_GENERIC')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) NotificationDeviceIdentifier

Constants

values → const List<NotificationDeviceIdentifier>
A constant List of the values in this enum, in order of their declaration.