toMap method
Converts this NotificationException to a Map suitable for sending over the platform channel.
Implementation
Map<String, dynamic> toMap() {
return {
'result': result.value,
'message': message,
};
}
Converts this NotificationException to a Map suitable for sending over the platform channel.
Map<String, dynamic> toMap() {
return {
'result': result.value,
'message': message,
};
}