NotificationVibrateParams class
Vibration notification parameters.
Constructors
-
NotificationVibrateParams({int? time, List<
int> ? pattern}) -
const
-
NotificationVibrateParams.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pattern
→ List<
int> ? -
Vibration pattern as a list of on/off durations in milliseconds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → int?
-
Vibration duration in milliseconds.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited