rawData property
The raw decoded barcode bytes.
The application can use this to convert to a specific charset if needed.
Implementation
final Uint8List? rawData;
The raw decoded barcode bytes.
The application can use this to convert to a specific charset if needed.
final Uint8List? rawData;