tokenizedData property
Structured (tokenized) data parsed from the scan result.
Non-null only when a structured symbology such as UDI was decoded.
Implementation
final TokenizedData? tokenizedData;
Structured (tokenized) data parsed from the scan result.
Non-null only when a structured symbology such as UDI was decoded.
final TokenizedData? tokenizedData;