ScannerConnectionType enum
Connection type of the scanner device.
Values
- internal → const ScannerConnectionType
-
const ScannerConnectionType('INTERNAL') - bluetoothSsi → const ScannerConnectionType
-
const ScannerConnectionType('BLUETOOTH_SSI') - serialSsi → const ScannerConnectionType
-
const ScannerConnectionType('SERIAL_SSI') - usb → const ScannerConnectionType
-
const ScannerConnectionType('USB') - pluggableSsi → const ScannerConnectionType
-
const ScannerConnectionType('PLUGGABLE_SSI') - undefined → const ScannerConnectionType
-
const ScannerConnectionType('UNDEFINED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → ScannerConnectionType
Constants
-
values
→ const List<
ScannerConnectionType> - A constant List of the values in this enum, in order of their declaration.