ScannerTriggerType enum

Inheritance
Available extensions

Values

hard → const ScannerTriggerType

Hardware (physical) trigger button.

const ScannerTriggerType('HARD')
softOnce → const ScannerTriggerType

Software trigger; fires once.

const ScannerTriggerType('SOFT_ONCE')
softAlways → const ScannerTriggerType

Software trigger; fires continuously.

const ScannerTriggerType('SOFT_ALWAYS')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) ScannerTriggerType

Constants

values → const List<ScannerTriggerType>
A constant List of the values in this enum, in order of their declaration.