StatusData class

Represents the current status of a scanner.

Passed to the StatusListener when the scanner state changes.

See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/barcode/StatusData/

Constructors

StatusData({ScannerStates? state, String? friendlyName})
const
StatusData.fromMap(Map<String, dynamic> map)
factory

Properties

friendlyName String?
The human-readable name of the scanner.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ScannerStates?
The current state of the scanner.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited