InterfaceParams class

Constructors

InterfaceParams({bool? displayBluetoothAddressBarcode, int? connectionEstablishTime})
const
InterfaceParams.fromMap(Map<String, dynamic> map)
factory

Properties

connectionEstablishTime int?
Time (seconds) to wait when establishing a Bluetooth connection.
final
displayBluetoothAddressBarcode bool?
Whether to display a Bluetooth address barcode for pairing.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited