displayBluetoothAddressBarcode property
Whether to display a Bluetooth address barcode for pairing.
Implementation
final bool? displayBluetoothAddressBarcode;
Whether to display a Bluetooth address barcode for pairing.
final bool? displayBluetoothAddressBarcode;