InverseOcr enum

Inheritance
Available extensions

Values

regularOnly → const InverseOcr
const InverseOcr('REGULAR_ONLY')
inverseOnly → const InverseOcr
const InverseOcr('INVERSE_ONLY')
autoDiscriminate → const InverseOcr
const InverseOcr('AUTO_DISCRIMINATE')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) InverseOcr

Constants

values → const List<InverseOcr>
A constant List of the values in this enum, in order of their declaration.