LinearSecurityLevel enum
Linear barcode security level.
Values
- shortOrCodabar → const LinearSecurityLevel
-
const LinearSecurityLevel('SHORT_OR_CODABAR') - allTwice → const LinearSecurityLevel
-
const LinearSecurityLevel('ALL_TWICE') - longAndShort → const LinearSecurityLevel
-
const LinearSecurityLevel('LONG_AND_SHORT') - allThrice → const LinearSecurityLevel
-
const LinearSecurityLevel('ALL_THRICE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → LinearSecurityLevel
Constants
-
values
→ const List<
LinearSecurityLevel> - A constant List of the values in this enum, in order of their declaration.