NGSimulScanMultiBarcodeParams class

Constructors

NGSimulScanMultiBarcodeParams({int? barcodeCount, bool? instantReporting, bool? reportDecodedBarcodes})
const
NGSimulScanMultiBarcodeParams.fromMap(Map<String, dynamic> map)
factory

Properties

barcodeCount int?
Number of barcodes to scan simultaneously.
final
hashCode int
The hash code for this object.
no setterinherited
instantReporting bool?
Whether to report barcodes instantly as decoded.
final
reportDecodedBarcodes bool?
Whether to report previously decoded barcodes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited