NGSimulScanParams class

Constructors

NGSimulScanParams({NGSimulScanMode? ngSimulScanMode, NGSimulScanMultiBarcodeParams? multiBarcodeParams})
const
NGSimulScanParams.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
multiBarcodeParams NGSimulScanMultiBarcodeParams?
Multi-barcode parameters for NG SimulScan.
final
ngSimulScanMode NGSimulScanMode?
NG SimulScan mode selection.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited