OcrAVariant enum

Inheritance
Available extensions

Values

fullAscii → const OcrAVariant
const OcrAVariant('FULL_ASCII')
reserved1 → const OcrAVariant
const OcrAVariant('RESERVED_1')
reserved2 → const OcrAVariant
const OcrAVariant('RESERVED_2')
banking → const OcrAVariant
const OcrAVariant('BANKING')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) OcrAVariant

Constants

values → const List<OcrAVariant>
A constant List of the values in this enum, in order of their declaration.