OcrBVariant enum
OCR-B variant selection.
Values
- fullAscii → const OcrBVariant
-
const OcrBVariant('FULL_ASCII') - banking → const OcrBVariant
-
const OcrBVariant('BANKING') - isbn1 → const OcrBVariant
-
const OcrBVariant('ISBN_1') - isbn2 → const OcrBVariant
-
const OcrBVariant('ISBN_2') - travelDocument1 → const OcrBVariant
-
const OcrBVariant('TRAVEL_DOCUMENT_1') - travelDocument2 → const OcrBVariant
-
const OcrBVariant('TRAVEL_DOCUMENT_2') - travelDocument3 → const OcrBVariant
-
const OcrBVariant('TRAVEL_DOCUMENT_3') - passport → const OcrBVariant
-
const OcrBVariant('PASSPORT') - visaTypeA → const OcrBVariant
-
const OcrBVariant('VISA_TYPE_A') - visaTypeB → const OcrBVariant
-
const OcrBVariant('VISA_TYPE_B') - icaoTravelDocument → const OcrBVariant
-
const OcrBVariant('ICAO_TRAVEL_DOCUMENT')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → OcrBVariant
Constants
-
values
→ const List<
OcrBVariant> - A constant List of the values in this enum, in order of their declaration.