OcrCheckDigitValidation enum

Inheritance
Available extensions

Values

none → const OcrCheckDigitValidation
const OcrCheckDigitValidation('NONE')
productAddRightToLeft → const OcrCheckDigitValidation
const OcrCheckDigitValidation('PRODUCT_ADD_RIGHT_TO_LEFT')
digitAddRightToLeft → const OcrCheckDigitValidation
const OcrCheckDigitValidation('DIGIT_ADD_RIGHT_TO_LEFT')
productAddLeftToRight → const OcrCheckDigitValidation
const OcrCheckDigitValidation('PRODUCT_ADD_LEFT_TO_RIGHT')
digitAddLeftToRight → const OcrCheckDigitValidation
const OcrCheckDigitValidation('DIGIT_ADD_LEFT_TO_RIGHT')
productAddRightToLeftSimpleRemainder → const OcrCheckDigitValidation
const OcrCheckDigitValidation('PRODUCT_ADD_RIGHT_TO_LEFT_SIMPLE_REMAINDER')
digitAddRightToLeftSimpleRemainder → const OcrCheckDigitValidation
const OcrCheckDigitValidation('DIGIT_ADD_RIGHT_TO_LEFT_SIMPLE_REMAINDER')
healthIndustryHibcc43 → const OcrCheckDigitValidation
const OcrCheckDigitValidation('HEALTH_INDUSTRY_HIBCC43')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) OcrCheckDigitValidation

Constants

values → const List<OcrCheckDigitValidation>
A constant List of the values in this enum, in order of their declaration.