OcrLines enum

Inheritance
Available extensions

Values

oneLine → const OcrLines
const OcrLines('ONE_LINE')
twoLines → const OcrLines
const OcrLines('TWO_LINES')
threeLines → const OcrLines
const OcrLines('THREE_LINES')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) OcrLines

Constants

values → const List<OcrLines>
A constant List of the values in this enum, in order of their declaration.