PoorQualityDecodeEffortLevel enum

Inheritance
Available extensions

Values

level0 → const PoorQualityDecodeEffortLevel
const PoorQualityDecodeEffortLevel('LEVEL_0')
level1 → const PoorQualityDecodeEffortLevel
const PoorQualityDecodeEffortLevel('LEVEL_1')
level2 → const PoorQualityDecodeEffortLevel
const PoorQualityDecodeEffortLevel('LEVEL_2')
level3 → const PoorQualityDecodeEffortLevel
const PoorQualityDecodeEffortLevel('LEVEL_3')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) PoorQualityDecodeEffortLevel

Constants

values → const List<PoorQualityDecodeEffortLevel>
A constant List of the values in this enum, in order of their declaration.