PresentationModeParams class
Presentation mode parameters for imager scanners.
Constructors
- PresentationModeParams({PresentationModeSensitivity? sensitivity})
-
const
-
PresentationModeParams.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitivity → PresentationModeSensitivity?
-
Sensitivity level of presentation mode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited