SecurityLevel enum
Barcode security level for duplicate symbol rejection.
Values
- level0 → const SecurityLevel
-
const SecurityLevel('LEVEL_0') - level1 → const SecurityLevel
-
const SecurityLevel('LEVEL_1') - level2 → const SecurityLevel
-
const SecurityLevel('LEVEL_2') - level3 → const SecurityLevel
-
const SecurityLevel('LEVEL_3')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → SecurityLevel
Constants
-
values
→ const List<
SecurityLevel> - A constant List of the values in this enum, in order of their declaration.