SignatureImageFormat enum

Inheritance
Available extensions

Values

jpeg → const SignatureImageFormat
const SignatureImageFormat('JPEG')
bmp → const SignatureImageFormat
const SignatureImageFormat('BMP')
tiff → const SignatureImageFormat
const SignatureImageFormat('TIFF')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) SignatureImageFormat

Constants

values → const List<SignatureImageFormat>
A constant List of the values in this enum, in order of their declaration.