SkipOnUnSupported enum

Determines scanner behaviour when an unsupported parameter is encountered.

See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/barcode/ScannerConfig/

Inheritance
Available extensions

Values

none → const SkipOnUnSupported
const SkipOnUnSupported('NONE')
unsupportedParam → const SkipOnUnSupported
const SkipOnUnSupported('UNSUPPORTED_PARAM')
unsupportedValue → const SkipOnUnSupported
const SkipOnUnSupported('UNSUPPORTED_VALUE')
all → const SkipOnUnSupported
const SkipOnUnSupported('ALL')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) SkipOnUnSupported

Constants

values → const List<SkipOnUnSupported>
A constant List of the values in this enum, in order of their declaration.