MxProfiles class final

Constructors

MxProfiles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

autoRotateState(bool enabled) String
bluetoothPairingPopupState(bool enabled) String
bluetoothPairingState(bool enabled) String
bluetoothState(bool enabled) String
enterpriseKeyboard({required String currentLocale, bool showVirtualKeyboard = true}) String
largeScreenTaskbarState(bool enabled) String
nfcPairingState(bool enabled) String
nfcState(bool enabled) String
notificationPullDownState(bool enabled) String
recentAppButtonState(bool enabled) String
screenBrightness(int level) String
screenLockType(int type) String
screenTimeout(int seconds) String
startActivity({String? actionName, String? package, String? className}) String
statusBarState(bool enabled) String
systemAppState({required String package, required bool enabled}) String

Constants

clearPairedDevices → const String
disconnectScanner → const String
fullDeviceWipe → const String
locateScanner → const String
reboot → const String
resetScanner → const String
unpairScanner → const String