KeyEventManager class

Listens for physical hardware-key presses on Zebra devices, mapped via the MX KeyMappingMgr CSP (configured through ProfileManager.addKeyListener).

emdk.keyEventManager.onKeyDown.listen((key) {
  if (key == KeyIdentifier.p1) { /* … */ }
});

Constructors

KeyEventManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
onKeyDown Stream<KeyIdentifier?>
Fires when a mapped key is pressed. Emits null for an unrecognised key value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited