CodaBarDecoder class
CodaBar decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- CodaBarDecoder
Constructors
- CodaBarDecoder({bool? enabled, int? length1, int? length2, bool? redundancy, bool? clsiEditing, bool? notisEditing})
-
const
-
CodaBarDecoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- clsiEditing → bool?
-
Whether to apply CLSI editing to the decoded data.
final
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length1 → int?
-
Minimum length of the barcode.
final
- length2 → int?
-
Maximum length of the barcode.
final
- notisEditing → bool?
-
Whether to apply NOTIS editing to the decoded data.
final
- redundancy → bool?
-
Whether to require two consecutive reads before reporting.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited