DutchPostalDecoder class
Dutch Postal decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- DutchPostalDecoder
Constructors
- DutchPostalDecoder({bool? enabled, bool? dutchPostal3S})
-
const
-
DutchPostalDecoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- dutchPostal3S → bool?
-
Whether to enable Dutch Postal 3S mode.
final
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited