SignatureDecoder class
Signature decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- SignatureDecoder
Constructors
- SignatureDecoder({bool? enabled, int? width, int? height, SignatureImageFormat? format, int? jpegQuality, SignatureImageBitsPerPixel? bpp})
-
const
-
SignatureDecoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- bpp → SignatureImageBitsPerPixel?
-
Bits per pixel for the output image.
final
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- format → SignatureImageFormat?
-
Output image format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Height (pixels) of the captured signature image.
final
- jpegQuality → int?
-
JPEG quality (1–100) when format is JPEG.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
Width (pixels) of the captured signature image.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited