UpcEanParamsDecoder class
UPC/EAN shared parameters decoder configuration.
- Inheritance
-
- Object
- BaseDecoder
- UpcEanParamsDecoder
Constructors
- UpcEanParamsDecoder({bool? enabled, bool? booklandCode, BooklandFormat? booklandFormat, bool? convertDataBarToUpcEan, bool? couponCode, bool? linearDecode, bool? randomWeightCheckDigit, SecurityLevel? securityLevel, bool? supplemental2, bool? supplemental5, SupplementalMode? supplementalMode, int? supplementalRetries, CouponReport? couponReport, bool? eanZeroExtend, bool? reducedQuietZone})
-
const
-
UpcEanParamsDecoder.fromMap(Map<
String, dynamic> map) -
factory
Properties
- booklandCode → bool?
-
Whether to decode Bookland EAN.
final
- booklandFormat → BooklandFormat?
-
Output format for Bookland EAN.
final
- convertDataBarToUpcEan → bool?
-
Whether to convert DataBar to UPC/EAN.
final
- couponCode → bool?
-
Whether to decode UPC coupon codes.
final
- couponReport → CouponReport?
-
final
- eanZeroExtend → bool?
-
Whether to zero-extend EAN-8 to EAN-13.
final
- enabled → bool?
-
Whether this symbology decoder is enabled.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- linearDecode → bool?
-
Whether to report linear decode component of composite barcodes.
final
- randomWeightCheckDigit → bool?
-
Whether to verify random-weight check digits.
final
- reducedQuietZone → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityLevel → SecurityLevel?
-
final
- supplemental2 → bool?
-
Whether to decode 2-digit supplementals.
final
- supplemental5 → bool?
-
Whether to decode 5-digit supplementals.
final
- supplementalMode → SupplementalMode?
-
final
- supplementalRetries → int?
-
Number of decode retries for supplemental barcodes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited