data/emdk_manager library

Classes

EMDKError
Represents an EMDK error with a primary code and optional sub-codes.
EMDKResults
Result object returned from profile and EMDK operations.
EMDKStatusData
Status data passed to the EMDKManager StatusListener.
ProfileResultData
Result data returned from an asynchronous profile processing call.

Enums

EMDKErrorCode
Primary EMDK error codes.
EMDKExtendedStatusCode
Extended status codes for detailed EMDK result reporting.
EMDKFeatureType
Feature types supported by the EMDK Manager.
EMDKStatusCode
Status codes returned from EMDKManager operations.
EMDKSubErrorCode
Sub-error codes for detailed EMDK error reporting.
EMDKVersionType
Identifies the component whose version is being queried.
ProfileFlag
Flags that control the action performed by processProfile.

Exceptions / Errors

EMDKException
Exception thrown by EMDK core operations (e.g. opening the EMDK manager or requesting a feature instance) when an error occurs at the SDK level.