EMDKError class
Represents an EMDK error with a primary code and optional sub-codes.
See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/EMDKError/
Constructors
-
EMDKError({EMDKErrorCode? errorCode, List<
EMDKSubErrorCode> ? subErrorCodes}) -
const
-
EMDKError.fromMap(Map<
String, dynamic> map) -
factory
Properties
- errorCode → EMDKErrorCode?
-
The primary error code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subErrorCodes
→ List<
EMDKSubErrorCode> ? -
List of sub-error codes for additional detail.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited