EMDKResults class
Result object returned from profile and EMDK operations.
Contains both a primary status code and an extended status code for more detailed error reporting.
See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/EMDKResults/
Constructors
- EMDKResults({EMDKStatusCode? statusCode, EMDKExtendedStatusCode? extendedStatusCode, String? statusString})
-
const
-
EMDKResults.fromMap(Map<
String, dynamic> map) -
factory
Properties
- extendedStatusCode → EMDKExtendedStatusCode?
-
Extended status code providing additional error detail.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → EMDKStatusCode?
-
Primary status code of the operation.
final
- statusString → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited