KeyIdentifier enum
Identifies a hardware key or button on a Zebra device for use with the
MX KeyMappingMgr CSP (KeyIdentifier parm).
The value of each entry is the exact string accepted by the
KeyIdentifier parm in the MX XML profile.
Not all devices have keys for every identifier. Attempting to map a key that is not present on the device will produce an error in the Result XML.
Values
- zero → const KeyIdentifier
-
The "0" key.
const KeyIdentifier('0') - one → const KeyIdentifier
-
The "1" key.
const KeyIdentifier('1') - two → const KeyIdentifier
-
The "2" key.
const KeyIdentifier('2') - three → const KeyIdentifier
-
The "3" key.
const KeyIdentifier('3') - four → const KeyIdentifier
-
The "4" key.
const KeyIdentifier('4') - five → const KeyIdentifier
-
The "5" key.
const KeyIdentifier('5') - six → const KeyIdentifier
-
The "6" key.
const KeyIdentifier('6') - seven → const KeyIdentifier
-
The "7" key.
const KeyIdentifier('7') - eight → const KeyIdentifier
-
The "8" key.
const KeyIdentifier('8') - nine → const KeyIdentifier
-
The "9" key.
const KeyIdentifier('9') - a → const KeyIdentifier
-
The "A" key.
const KeyIdentifier('A') - b → const KeyIdentifier
-
The "B" key.
const KeyIdentifier('B') - c → const KeyIdentifier
-
The "C" key.
const KeyIdentifier('C') - d → const KeyIdentifier
-
The "D" key.
const KeyIdentifier('D') - e → const KeyIdentifier
-
The "E" key.
const KeyIdentifier('E') - f → const KeyIdentifier
-
The "F" key.
const KeyIdentifier('F') - g → const KeyIdentifier
-
The "G" key.
const KeyIdentifier('G') - h → const KeyIdentifier
-
The "H" key.
const KeyIdentifier('H') - i → const KeyIdentifier
-
The "I" key.
const KeyIdentifier('I') - j → const KeyIdentifier
-
The "J" key.
const KeyIdentifier('J') - k → const KeyIdentifier
-
The "K" key.
const KeyIdentifier('K') - l → const KeyIdentifier
-
The "L" key.
const KeyIdentifier('L') - m → const KeyIdentifier
-
The "M" key.
const KeyIdentifier('M') - n → const KeyIdentifier
-
The "N" key.
const KeyIdentifier('N') - o → const KeyIdentifier
-
The "O" key.
const KeyIdentifier('O') - p → const KeyIdentifier
-
The "P" key.
const KeyIdentifier('P') - q → const KeyIdentifier
-
The "Q" key.
const KeyIdentifier('Q') - r → const KeyIdentifier
-
The "R" key.
const KeyIdentifier('R') - s → const KeyIdentifier
-
The "S" key.
const KeyIdentifier('S') - t → const KeyIdentifier
-
The "T" key.
const KeyIdentifier('T') - u → const KeyIdentifier
-
The "U" key.
const KeyIdentifier('U') - v → const KeyIdentifier
-
The "V" key.
const KeyIdentifier('V') - w → const KeyIdentifier
-
The "W" key.
const KeyIdentifier('W') - x → const KeyIdentifier
-
The "X" key.
const KeyIdentifier('X') - y → const KeyIdentifier
-
The "Y" key.
const KeyIdentifier('Y') - z → const KeyIdentifier
-
The "Z" key.
const KeyIdentifier('Z') - f1 → const KeyIdentifier
-
The "F1" function key.
const KeyIdentifier('F1') - f2 → const KeyIdentifier
-
The "F2" function key.
const KeyIdentifier('F2') - f3 → const KeyIdentifier
-
The "F3" function key.
const KeyIdentifier('F3') - f4 → const KeyIdentifier
-
The "F4" function key.
const KeyIdentifier('F4') - f5 → const KeyIdentifier
-
The "F5" function key.
const KeyIdentifier('F5') - f6 → const KeyIdentifier
-
The "F6" function key.
const KeyIdentifier('F6') - f7 → const KeyIdentifier
-
The "F7" function key.
const KeyIdentifier('F7') - f8 → const KeyIdentifier
-
The "F8" function key.
const KeyIdentifier('F8') - f9 → const KeyIdentifier
-
The "F9" function key.
const KeyIdentifier('F9') - f10 → const KeyIdentifier
-
The "F10" function key.
const KeyIdentifier('F10') - f11 → const KeyIdentifier
-
The "F11" function key.
const KeyIdentifier('F11') - f12 → const KeyIdentifier
-
The "F12" function key.
const KeyIdentifier('F12') - dot → const KeyIdentifier
-
The period / dot key.
const KeyIdentifier('DOT') - comma → const KeyIdentifier
-
The comma key. (MX 8.3+)
const KeyIdentifier('COMMA') - star → const KeyIdentifier
-
The "Star" key (not the asterisk key).
const KeyIdentifier('STAR') - pound → const KeyIdentifier
-
The pound / number-sign ("#") key.
const KeyIdentifier('POUND') - enter → const KeyIdentifier
-
The Enter key (may differ from the Return key).
const KeyIdentifier('ENTER') - up → const KeyIdentifier
-
The Up-arrow key.
const KeyIdentifier('UP') - down → const KeyIdentifier
-
The Down-arrow key.
const KeyIdentifier('DOWN') - left → const KeyIdentifier
-
The Left-arrow key.
const KeyIdentifier('LEFT') - right → const KeyIdentifier
-
The Right-arrow key.
const KeyIdentifier('RIGHT') -
Centre button of a four-way navigational pad. (MX 10.4+)
const KeyIdentifier('NAV_OK') - escape → const KeyIdentifier
-
The Escape / ESC key.
const KeyIdentifier('ESC') - backspace → const KeyIdentifier
-
The Backspace / BKSP key.
const KeyIdentifier('BACKSPACE') - delete → const KeyIdentifier
-
The Delete / DEL key. (MX 11.3+)
const KeyIdentifier('DELETE') - insert → const KeyIdentifier
-
The Insert / INS key. (MX 11.3+)
const KeyIdentifier('INSERT') - space → const KeyIdentifier
-
The Space key / spacebar.
const KeyIdentifier('SPACE') - returnKey → const KeyIdentifier
-
The Return key (may differ from the Enter key).
const KeyIdentifier('RETURN') - clear → const KeyIdentifier
-
The Clear key.
const KeyIdentifier('CLR') - fieldExit → const KeyIdentifier
-
The Field Exit key.
const KeyIdentifier('FIELD_EXIT') - alt → const KeyIdentifier
-
The Alt modifier/meta key.
const KeyIdentifier('ALT') - ctrl → const KeyIdentifier
-
The Control / CTRL modifier/meta key.
const KeyIdentifier('CTRL') - shift → const KeyIdentifier
-
The Shift modifier/meta key.
const KeyIdentifier('SHIFT') - func → const KeyIdentifier
-
The Function modifier/meta key. (MX 9.2+)
const KeyIdentifier('FUNC') - alpha → const KeyIdentifier
-
The Alpha modifier/meta key. (MX 9.2+)
const KeyIdentifier('ALPHA') - cl → const KeyIdentifier
-
The key marked "CL" on some devices. (MX 10.4+)
const KeyIdentifier('CL') - fn → const KeyIdentifier
-
The key marked "FN" on some devices. (MX 10.4+)
const KeyIdentifier('FN') - blue → const KeyIdentifier
-
The completely blue key (sometimes called the "Function" key).
const KeyIdentifier('BLUE') - orange → const KeyIdentifier
-
The completely orange key (sometimes called the "Alpha" key).
const KeyIdentifier('ORANGE') - diamond → const KeyIdentifier
-
The key marked with a "diamond" symbol. (MX 8.3+)
const KeyIdentifier('DIAMOND') - green → const KeyIdentifier
-
The key with a green dot on it.
const KeyIdentifier('GREEN') - red → const KeyIdentifier
-
The key with a red dot on it.
const KeyIdentifier('RED') - volumeUp → const KeyIdentifier
-
The Volume Up key.
const KeyIdentifier('VOLUMEUP') - volumeDown → const KeyIdentifier
-
The Volume Down key.
const KeyIdentifier('VOLUMEDOWN') - brightnessUp → const KeyIdentifier
-
The key that increases screen brightness. (MX 7.1+, Zebra VC80x)
const KeyIdentifier('BRIGHTNESSUP') - brightnessDown → const KeyIdentifier
-
The key that decreases screen brightness. (MX 7.1+, Zebra VC80x)
const KeyIdentifier('BRIGHTNESSDOWN') - keyLightUp → const KeyIdentifier
-
The key that increases keyboard backlight brightness. (MX 8.3+)
const KeyIdentifier('KEYLIGHTUP') - keyLightDown → const KeyIdentifier
-
The key that decreases keyboard backlight brightness. (MX 8.3+)
const KeyIdentifier('KEYLIGHTDOWN') - scan → const KeyIdentifier
-
The key or button that invokes the device scanner.
const KeyIdentifier('SCAN') - gripTrigger → const KeyIdentifier
-
Usually the upper-most button on the hand grip.
const KeyIdentifier('GRIP_TRIGGER') - gripTrigger2 → const KeyIdentifier
-
The lower button on the hand grip when two grip buttons are present. (MX 6.1+)
const KeyIdentifier('GRIP_TRIGGER_2') - leftTrigger1 → const KeyIdentifier
-
Usually the upper-most button on the left side of the device.
const KeyIdentifier('LEFT_TRIGGER_1') - leftTrigger2 → const KeyIdentifier
-
The lower button on the left side when two left buttons are present.
const KeyIdentifier('LEFT_TRIGGER_2') - rightTrigger1 → const KeyIdentifier
-
Usually the upper-most button on the right side of the device.
const KeyIdentifier('RIGHT_TRIGGER_1') - rightTrigger2 → const KeyIdentifier
-
The lower button on the right side when two right buttons are present.
const KeyIdentifier('RIGHT_TRIGGER_2') - leftTrigger → const KeyIdentifier
-
Button on the left side of a Zebra MC33 device. (MX 7.2+)
const KeyIdentifier('LEFT_TRIGGER') - rightTrigger → const KeyIdentifier
-
Button on the right side of a Zebra MC33 device. (MX 7.2+)
const KeyIdentifier('RIGHT_TRIGGER') - centerTrigger → const KeyIdentifier
-
Button at the top of the keypad on a Zebra MC33 device. (MX 7.2+)
const KeyIdentifier('CENTER_TRIGGER') - gunTrigger → const KeyIdentifier
-
Button on the front of the handle of a Zebra MC33 device. (MX 7.2+)
const KeyIdentifier('GUN_TRIGGER') - p1 → const KeyIdentifier
-
The button marked "P1". (MX 5.2+)
const KeyIdentifier('P1') - p2 → const KeyIdentifier
-
The button marked "P2". (MX 5.2+)
const KeyIdentifier('P2') - p3 → const KeyIdentifier
-
The button marked "P3". (MX 5.2+)
const KeyIdentifier('P3') - p4 → const KeyIdentifier
-
The button marked "P4". (MX 7.2+)
const KeyIdentifier('P4') - p5 → const KeyIdentifier
-
The button marked "P5". (MX 8.3+)
const KeyIdentifier('P5') - p6 → const KeyIdentifier
-
The button marked "P6". (MX 8.3+)
const KeyIdentifier('P6') - rearButton → const KeyIdentifier
-
The button on the rear of the device. (MX 6.1+)
const KeyIdentifier('REAR_BUTTON') - leftExternalTrigger → const KeyIdentifier
-
The trigger button on the left side of an external triggering device. (MX 5.2+)
const KeyIdentifier('LEFT_EXTERNAL_TRIGGER') - rightExternalTrigger → const KeyIdentifier
-
The trigger button on the right side of an external triggering device. (MX 5.2+)
const KeyIdentifier('RIGHT_EXTERNAL_TRIGGER') - bluetoothRemoteTrigger1 → const KeyIdentifier
-
The primary trigger button on a Bluetooth-connected barcode scanner. (MX 9.2+)
const KeyIdentifier('BLUETOOTH_REMOTE_TRIGGER_1') - bluetoothRemoteTrigger2 → const KeyIdentifier
-
The secondary trigger button on a Bluetooth-connected barcode scanner. (MX 9.2+)
const KeyIdentifier('BLUETOOTH_REMOTE_TRIGGER_2') -
The touch-sensitive navigation pad on a device. (MX 6.2+)
const KeyIdentifier('NAV_PAD') - m1 → const KeyIdentifier
-
The Zebra VC80x M1 key. (MX 7.1+)
const KeyIdentifier('M1') - m2 → const KeyIdentifier
-
The Zebra VC80x M2 key. (MX 7.1+)
const KeyIdentifier('M2') - m3 → const KeyIdentifier
-
The Zebra VC80x M3 key. (MX 7.1+)
const KeyIdentifier('M3') - m4 → const KeyIdentifier
-
The Zebra VC80x M4 key. (MX 7.1+)
const KeyIdentifier('M4') - m5 → const KeyIdentifier
-
The Zebra VC80x M5 key. (MX 7.1+)
const KeyIdentifier('M5') - m6 → const KeyIdentifier
-
The Zebra VC80x M6 key. (MX 7.1+)
const KeyIdentifier('M6') - headsetHook → const KeyIdentifier
-
The headset pick-up / hang-up button.
const KeyIdentifier('HEADSET_HOOK') - back → const KeyIdentifier
-
The Back key, button or capacitive button.
const KeyIdentifier('BACK') - home → const KeyIdentifier
-
The Home key, button or capacitive button.
const KeyIdentifier('HOME') -
The Menu key, button or capacitive button.
const KeyIdentifier('MENU') - recent → const KeyIdentifier
-
The Recent Apps key, button or capacitive button.
const KeyIdentifier('RECENT') - search → const KeyIdentifier
-
The Search key, button or capacitive button.
const KeyIdentifier('SEARCH') - keyLight → const KeyIdentifier
-
The keyboard backlight key or button.
const KeyIdentifier('KEYLIGHT') - lamp → const KeyIdentifier
-
The display-screen backlight key or button.
const KeyIdentifier('LAMP') - power → const KeyIdentifier
-
The Power (on/off) key or button.
const KeyIdentifier('POWER') - rotate → const KeyIdentifier
-
The key that causes the screen to change orientation. (MX 9.2+)
const KeyIdentifier('ROTATE') - plus → const KeyIdentifier
-
The key that inputs a plus (+) sign. (MX 9.2+)
const KeyIdentifier('PLUS') - minus → const KeyIdentifier
-
The key that inputs a minus (-) sign or hyphen. (MX 9.2+)
const KeyIdentifier('MINUS') - pause → const KeyIdentifier
-
The key that inputs a pause/break command. (MX 9.2+)
const KeyIdentifier('PAUSE') - end → const KeyIdentifier
-
The key that moves the cursor to the end of the current page. (MX 9.2+)
const KeyIdentifier('END') - pageUp → const KeyIdentifier
-
The key that moves the cursor up one page. (MX 9.2+)
const KeyIdentifier('PAGEUP') - pageDown → const KeyIdentifier
-
The key that moves the cursor down one page. (MX 9.2+)
const KeyIdentifier('PAGEDOWN') - tab → const KeyIdentifier
-
The key that inputs a tab character. (MX 10.2+)
const KeyIdentifier('TAB') - doNotDisturb → const KeyIdentifier
-
Button on the clip-mount accessory for the Zebra WS50. (MX 13.3+)
const KeyIdentifier('DO_NOT_DISTURB') - topButton → const KeyIdentifier
-
Recessed emergency-call button on top of the Zebra EM45. (MX 13.5+)
const KeyIdentifier('TOP_BUTTON') - rightButton → const KeyIdentifier
-
Button on the right side of the Zebra EM45. (MX 13.5+)
const KeyIdentifier('RIGHT_BUTTON') - channelSwitch → const KeyIdentifier
-
Upper push-to-talk channel-switch button on the Zebra FR55. (MX 14.2+, API 34+)
const KeyIdentifier('CHANNEL_SWITCH') - alertButton → const KeyIdentifier
-
Red emergency-call button on top of the Zebra FR55. (MX 14.2+, API 34+)
const KeyIdentifier('ALERT_BUTTON') - duress → const KeyIdentifier
-
Dedicated emergency-call button on some Zebra devices. (MX 15.0+, API 34+)
const KeyIdentifier('DURESS') - custom → const KeyIdentifier
-
Used when remapping a key with a custom name. (MX 15.2+, API 34+)
const KeyIdentifier('CUSTOM')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → KeyIdentifier
Constants
-
values
→ const List<
KeyIdentifier> - A constant List of the values in this enum, in order of their declaration.