NotificationDeviceInfo class

Represents info about a connected notification device (e.g. RS6000).

See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/notification/DeviceInfo/

Constructors

NotificationDeviceInfo({String? friendlyName, String? modelNumber, NotificationDeviceType? deviceType, NotificationConnectionType? connectionType, NotificationDeviceIdentifier? deviceIdentifier, bool? isDefaultDevice, bool? isConnected, bool? isLEDSupported, bool? isBeepSupported, bool? isVibrateSupported})
const
NotificationDeviceInfo.fromMap(Map<String, dynamic> map)
factory

Properties

connectionType NotificationConnectionType?
Connection type.
final
deviceIdentifier NotificationDeviceIdentifier?
Device identifier.
final
deviceType NotificationDeviceType?
Device type.
final
friendlyName String?
Human-readable device name.
final
hashCode int
The hash code for this object.
no setterinherited
isBeepSupported bool?
Whether beep notification is supported.
final
isConnected bool?
Whether the device is currently connected.
final
isDefaultDevice bool?
Whether this is the default notification device.
final
isLEDSupported bool?
Whether LED notification is supported.
final
isVibrateSupported bool?
Whether vibrate notification is supported.
final
modelNumber String?
Device model number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited