NotificationLEDParams class
LED notification parameters.
Constructors
- NotificationLEDParams({int? color, int? onTime, int? offTime, int? repeatCount})
-
const
-
NotificationLEDParams.fromMap(Map<
String, dynamic> map) -
factory
Properties
- color → int?
-
LED color as an Android Color integer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offTime → int?
-
Off-time of the LED blink in milliseconds.
final
- onTime → int?
-
On-time of the LED blink in milliseconds.
final
- repeatCount → int?
-
Number of times to repeat; use repeatInfinite for continuous.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- repeatInfinite → const int
- Constant for infinite repeat.