NotificationResults enum
Result codes for notification operations.
Values
- success → const NotificationResults
-
const NotificationResults('SUCCESS') - deviceNotConnected → const NotificationResults
-
const NotificationResults('DEVICE_NOT_CONNECTED') - deviceInvalid → const NotificationResults
-
const NotificationResults('DEVICE_INVALID') - deviceNotEnabled → const NotificationResults
-
const NotificationResults('DEVICE_NOT_ENABLED') - deviceAlreadyEnabled → const NotificationResults
-
const NotificationResults('DEVICE_ALREADY_ENABLED') - failure → const NotificationResults
-
const NotificationResults('FAILURE') - invalidValue → const NotificationResults
-
const NotificationResults('INVALID_VALUE') - featureNotSupported → const NotificationResults
-
const NotificationResults('FEATURE_NOT_SUPPORTED') - commandNotSupported → const NotificationResults
-
const NotificationResults('COMMAND_NOT_SUPPORTED') - undefined → const NotificationResults
-
const NotificationResults('UNDEFINED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → NotificationResults
Constants
-
values
→ const List<
NotificationResults> - A constant List of the values in this enum, in order of their declaration.