Token class
A single token extracted from UDI or other structured barcode data.
Tokens are produced when the scanner parses a structured symbology (e.g. UDI) into labelled key/value pairs.
Constructors
Properties
- data → String?
-
The decoded string value for this token.
final
- dataType → String?
-
The data type of this token's value (e.g.
"string","date").final - format → String?
-
The format description of this token.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
The key (field name) that identifies this token in the structured data.
final
- rawData → Uint8List?
-
The raw byte representation of the token data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this Token to a Map suitable for sending over the platform channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited