BarcodeManagerDeviceIdentifier enum
Identifies specific scanner hardware devices.
Used when requesting a specific scanner from BarcodeManager.
Values
- defaultDevice → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('DEFAULT') - internalCamera1 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('INTERNAL_CAMERA1') - internalImager1 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('INTERNAL_IMAGER1') - internalLaser1 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('INTERNAL_LASER1') - bluetoothImager1 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_IMAGER1') - pluggableLaser1 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('PLUGGABLE_LASER1') - bluetoothImagerRs6000 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_IMAGER_RS6000') - pluggableImagerRs5000 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('PLUGGABLE_IMAGER_RS5000') - bluetoothImagerDs3678 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_IMAGER_DS3678') - pluggableImagerDs3608 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('PLUGGABLE_IMAGER_DS3608') - bluetoothLaserLi3678 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_LASER_LI3678') - pluggableLaserLi3608 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('PLUGGABLE_LASER_LI3608') - bluetoothImagerDs2278 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_IMAGER_DS2278') - bluetoothImagerDs8178 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_IMAGER_DS8178') - bluetoothImagerRs5100 → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('BLUETOOTH_IMAGER_RS5100') - undefined → const BarcodeManagerDeviceIdentifier
-
const BarcodeManagerDeviceIdentifier('UNDEFINED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
BarcodeManagerDeviceIdentifier> - A constant List of the values in this enum, in order of their declaration.