ScannerStates enum
Current operational state of the scanner hardware.
See: https://techdocs.zebra.com/emdk-for-android/latest/api/reference/com/symbol/emdk/barcode/StatusData/
Values
- idle → const ScannerStates
-
Scanner is idle, waiting for a trigger.
const ScannerStates('IDLE') - waiting → const ScannerStates
-
Scanner is waiting for a scan to complete.
const ScannerStates('WAITING') - scanning → const ScannerStates
-
Scanner is actively scanning.
const ScannerStates('SCANNING') - disabled → const ScannerStates
-
Scanner is disabled.
const ScannerStates('DISABLED') - error → const ScannerStates
-
Scanner encountered an error.
const ScannerStates('ERROR')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → ScannerStates
Constants
-
values
→ const List<
ScannerStates> - A constant List of the values in this enum, in order of their declaration.