CameraSpecific class

Constructors

CameraSpecific({ContinuousRead? continuousRead, int? beamTimer, int? viewfinderSize, int? viewfinderOffsetX, int? viewfinderOffsetY, LinearSecurityLevel? linearSecurityLevel, IlluminationMode? illuminationMode, Inverse1DMode? inverse1DMode, ViewFinderMode? viewfinderMode, OneDQuietZoneLevel? oneDQuietZoneLevel, PoorQualityDecodeEffortLevel? poorQualityDecodeEffortLevel, PicklistEx? picklistEx, AimType? aimType, int? aimTimer, int? sameSymbolTimeout, int? differentSymbolTimeout, CharacterSet? characterSetSelection, AutoCharacterSetFailureOption? autoCharacterSetFailureOption, List<AutoCharacterSetPreference>? autoCharacterSetPreferredOrder, ScanMode? scanMode, int? zoom, bool? digimarcDecoding})
const
CameraSpecific.fromMap(Map<String, dynamic> map)
factory

Properties

aimTimer int?
Duration (ms) of the aiming phase.
final
aimType AimType?
Aim type for triggering.
final
autoCharacterSetFailureOption AutoCharacterSetFailureOption?
Failure option for auto character set detection.
final
autoCharacterSetPreferredOrder List<AutoCharacterSetPreference>?
Preferred character set order for auto detection.
final
beamTimer int?
Duration (ms) the beam stays on after trigger.
final
characterSetSelection CharacterSet?
Character set for decoded data.
final
continuousRead ContinuousRead?
Continuous read parameters.
final
differentSymbolTimeout int?
Timeout (ms) for different-symbol re-read.
final
digimarcDecoding bool?
Whether Digimarc decoding is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
illuminationMode IlluminationMode?
Illumination (torch) mode.
final
inverse1DMode Inverse1DMode?
Inverse 1D barcode decoding mode.
final
linearSecurityLevel LinearSecurityLevel?
Linear security level.
final
oneDQuietZoneLevel OneDQuietZoneLevel?
1D quiet zone tolerance level.
final
picklistEx PicklistEx?
Extended picklist mode setting.
final
poorQualityDecodeEffortLevel PoorQualityDecodeEffortLevel?
Effort level for decoding poor-quality barcodes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameSymbolTimeout int?
Timeout (ms) for same-symbol re-read.
final
scanMode ScanMode?
Scan mode (single, UDI, multi-barcode).
final
viewfinderMode ViewFinderMode?
Viewfinder display mode.
final
viewfinderOffsetX int?
Horizontal offset of the viewfinder.
final
viewfinderOffsetY int?
Vertical offset of the viewfinder.
final
viewfinderSize int?
Viewfinder width as a percentage of the screen.
final
zoom int?
Zoom factor for the camera.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited