CharacterSet enum

Inheritance
Available extensions

Values

auto → const CharacterSet
const CharacterSet('AUTO')
utf8 → const CharacterSet
const CharacterSet('UTF_8')
iso88591 → const CharacterSet
const CharacterSet('ISO_8859_1')
shiftJis → const CharacterSet
const CharacterSet('Shift_JIS')
gb18030 → const CharacterSet
const CharacterSet('GB18030')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) CharacterSet

Constants

values → const List<CharacterSet>
A constant List of the values in this enum, in order of their declaration.