ContinuousRead class
Continuous read parameters shared by multiple reader types.
Constructors
- ContinuousRead({bool? isContinuousScan, int? sameSymbolTimeout, int? differentSymbolTimeout})
-
const
-
ContinuousRead.fromMap(Map<
String, dynamic> map) -
factory
Properties
- differentSymbolTimeout → int?
-
Timeout (ms) before a different symbol can be decoded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isContinuousScan → bool?
-
Whether continuous scan mode is enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameSymbolTimeout → int?
-
Timeout (ms) before the same symbol can be decoded again.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited