LaserSpecific class
Parameters specific to laser-type scanners.
Constructors
-
LaserSpecific({ContinuousRead? continuousRead, int? beamTimer, LinearSecurityLevel? linearSecurityLevel, Inverse1DMode? inverse1DMode, PowerMode? powerMode, OneDQuietZoneLevel? oneDQuietZoneLevel, PoorQualityDecodeEffortLevel? poorQualityDecodeEffortLevel, AdaptiveScanning? adaptiveScanning, BeamWidth? beamWidth, AimType? aimType, int? aimTimer, int? sameSymbolTimeout, int? differentSymbolTimeout, CharacterSet? characterSetSelection, AutoCharacterSetFailureOption? autoCharacterSetFailureOption, List<
AutoCharacterSetPreference> ? autoCharacterSetPreferredOrder, bool? disconnectOnExit, int? connectionIdleTime, PairAfterScannerReboot? pairAfterScannerReboot}) -
const
-
LaserSpecific.fromMap(Map<
String, dynamic> map) -
factory
Properties
- adaptiveScanning → AdaptiveScanning?
-
Adaptive scanning mode.
final
- aimTimer → int?
-
Duration (ms) of the aiming beam.
final
- aimType → AimType?
-
Aim type for triggering.
final
- autoCharacterSetFailureOption → AutoCharacterSetFailureOption?
-
Failure option for auto character set detection.
final
-
autoCharacterSetPreferredOrder
→ List<
AutoCharacterSetPreference> ? -
Preferred character set order for auto detection.
final
- beamTimer → int?
-
Duration (ms) the beam stays on after trigger.
final
- beamWidth → BeamWidth?
-
Beam width setting.
final
- characterSetSelection → CharacterSet?
-
Character set for decoded data.
final
- connectionIdleTime → int?
-
Idle timeout (seconds) before disconnecting.
final
- continuousRead → ContinuousRead?
-
Continuous read parameters.
final
- differentSymbolTimeout → int?
-
Timeout (ms) for different-symbol re-read.
final
- disconnectOnExit → bool?
-
Whether to disconnect scanner on application exit.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inverse1DMode → Inverse1DMode?
-
Inverse 1D barcode decoding mode.
final
- linearSecurityLevel → LinearSecurityLevel?
-
Linear security level.
final
- oneDQuietZoneLevel → OneDQuietZoneLevel?
-
1D quiet zone tolerance level.
final
- pairAfterScannerReboot → PairAfterScannerReboot?
-
Whether to re-pair after scanner reboot.
final
- poorQualityDecodeEffortLevel → PoorQualityDecodeEffortLevel?
-
Effort level for decoding poor-quality barcodes.
final
- powerMode → PowerMode?
-
Power mode for laser.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameSymbolTimeout → int?
-
Timeout (ms) for same-symbol re-read.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited