OcrOrientation enum
OCR text orientation.
Values
- degree0 → const OcrOrientation
-
const OcrOrientation('DEGREE_0') - degree270 → const OcrOrientation
-
const OcrOrientation('DEGREE_270') - degree180 → const OcrOrientation
-
const OcrOrientation('DEGREE_180') - degree90 → const OcrOrientation
-
const OcrOrientation('DEGREE_90') - omnidirectional → const OcrOrientation
-
const OcrOrientation('OMNIDIRECTIONAL')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → OcrOrientation
Constants
-
values
→ const List<
OcrOrientation> - A constant List of the values in this enum, in order of their declaration.