OcrParams class

Constructors

OcrParams({InverseOcr? inverseOcr, OcrLines? ocrLines, int? maxCharacters, int? minCharacters, int? quietZone, String? template, OcrOrientation? orientation, String? subset, int? checkDigitModulus, String? checkDigitMultiplier, OcrCheckDigitValidation? checkDigitValidation})
const
OcrParams.fromMap(Map<String, dynamic> map)
factory

Properties

checkDigitModulus int?
Check digit modulus value.
final
checkDigitMultiplier String?
Check digit multiplier string.
final
checkDigitValidation OcrCheckDigitValidation?
Check digit validation method.
final
hashCode int
The hash code for this object.
no setterinherited
inverseOcr InverseOcr?
Inverse OCR mode (regular/inverse/auto).
final
maxCharacters int?
Maximum number of characters to decode.
final
minCharacters int?
Minimum number of characters to decode.
final
ocrLines OcrLines?
Number of OCR lines to read.
final
orientation OcrOrientation?
Orientation of the OCR text.
final
quietZone int?
Quiet zone size for OCR.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subset String?
Character subset for OCR decoding.
final
template String?
OCR template string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited