ReaderSpecific class
Reader-specific parameters; contains sub-objects for each scanner type.
Constructors
- ReaderSpecific({ImagerSpecific? imagerSpecific, CameraSpecific? cameraSpecific, LaserSpecific? laserSpecific})
-
const
-
ReaderSpecific.fromMap(Map<
String, dynamic> map) -
factory
Properties
- cameraSpecific → CameraSpecific?
-
Parameters specific to camera scanners.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imagerSpecific → ImagerSpecific?
-
Parameters specific to imager scanners.
final
- laserSpecific → LaserSpecific?
-
Parameters specific to laser scanners.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited