ScanParams class
Parameters controlling the scan session feedback and output format.
Constructors
- ScanParams({CodeIdType? codeIdType, String? decodeAudioFeedbackUri, bool? decodeHapticFeedback, int? decodeLEDTime, AudioStreamType? audioStreamType, bool? decodeLEDFeedback, DecodeLEDFeedbackMode? decodeLEDFeedbackMode, DecodeAudioFeedbackMode? decodeAudioFeedbackMode, bool? decodeScreenNotification, int? decodeScreenNotificationTime, int? decodeScreenTranslucencyLevel})
-
const
-
ScanParams.fromMap(Map<
String, dynamic> map) -
factory
Properties
- audioStreamType → AudioStreamType?
-
Audio stream type used for the decode beep.
final
- codeIdType → CodeIdType?
-
The code ID type prepended to barcode data.
final
- decodeAudioFeedbackMode → DecodeAudioFeedbackMode?
-
Audio feedback mode for remote scanners.
final
- decodeAudioFeedbackUri → String?
-
URI of the audio file to play on a successful decode.
final
- decodeHapticFeedback → bool?
-
Whether to provide haptic (vibration) feedback on decode.
final
- decodeLEDFeedback → bool?
-
Whether to illuminate the LED on decode.
final
- decodeLEDFeedbackMode → DecodeLEDFeedbackMode?
-
LED feedback mode for remote scanners.
final
- decodeLEDTime → int?
-
Duration in milliseconds of the decode LED indicator.
final
- decodeScreenNotification → bool?
-
Whether to show an on-screen notification on decode.
final
- decodeScreenNotificationTime → int?
-
Duration in milliseconds for the on-screen decode notification.
final
- decodeScreenTranslucencyLevel → int?
-
Translucency level (0–100) of the on-screen decode notification.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited