ScannerConfig class
Configuration class for the Zebra barcode scanner.
Controls all aspects of scanner behaviour including scan parameters, reader parameters, decoder parameters, and multi-barcode modes.
Constructors
- ScannerConfig({SkipOnUnSupported? skipOnUnsupported, ScanParams? scanParams, DecoderParams? decoderParams, ReaderParams? readerParams, NGSimulScanParams? ngSimulScanParams, UdiParams? udiParams, MultiBarcodeParams? multiBarcodeParams, OcrParams? ocrParams})
-
const
-
ScannerConfig.fromMap(Map<
String, dynamic> map) -
factory
Properties
- decoderParams → DecoderParams?
-
Decoder parameters controlling which symbologies are enabled and their options.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- multiBarcodeParams → MultiBarcodeParams?
-
Multi-barcode scanning parameters.
final
- ngSimulScanParams → NGSimulScanParams?
-
NG SimulScan parameters for multi-barcode scanning.
final
- ocrParams → OcrParams?
-
OCR (Optical Character Recognition) parameters.
final
- readerParams → ReaderParams?
-
Reader parameters controlling the hardware scanner behaviour.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanParams → ScanParams?
-
Parameters that control the scan session (audio, LED, etc.).
final
- skipOnUnsupported → SkipOnUnSupported?
-
Determines behaviour when an unsupported parameter is encountered.
final
- udiParams → UdiParams?
-
UDI (Unique Device Identifier) parsing parameters.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited