SupplementalMode enum

Inheritance
Available extensions

Values

no → const SupplementalMode
const SupplementalMode('NO')
always → const SupplementalMode
const SupplementalMode('ALWAYS')
auto → const SupplementalMode
const SupplementalMode('AUTO')
smart → const SupplementalMode
const SupplementalMode('SMART')
s378379 → const SupplementalMode
const SupplementalMode('S_378_379')
s978979 → const SupplementalMode
const SupplementalMode('S_978_979')
s414419434439 → const SupplementalMode
const SupplementalMode('S_414_419_434_439')
s977 → const SupplementalMode
const SupplementalMode('S_977')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String value) SupplementalMode

Constants

values → const List<SupplementalMode>
A constant List of the values in this enum, in order of their declaration.