UdiParams class
Parameters controlling UDI (Unique Device Identifier) barcode parsing.
Constructors
Properties
- enableGS1 → bool?
-
Whether GS1 UDI parsing is enabled.
final
- enableHIBCC → bool?
-
Whether HIBCC UDI parsing is enabled.
final
- enableICCBBA → bool?
-
Whether ICCBBA UDI parsing is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited