NotificationManager class
Zebra NotificationManager + NotificationDevice operations (Pigeon-backed).
Failures arrive as a typed NotificationException.
Constructors
- NotificationManager({NotificationHostApi? api})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deinitDevice(
) → Future< bool> -
getConnectedDevices(
) → Future< List< NotificationDeviceInfo> > -
getDeviceInfo(
) → Future< NotificationDeviceInfo?> -
getSupportedDevices(
) → Future< List< NotificationDeviceInfo> > -
initDevice(
String friendlyName) → Future< bool> -
isEnabled(
) → Future< bool> - Whether the active notification device is currently enabled.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
NotificationCommand command) → Future< bool> - Triggers a LED / beep / vibrate NotificationCommand on the active device.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited